@@ -122,7 +122,21 @@ bool UIDaemonHandler::IsService(QString name)
 
 bool UIDaemonHandler::IsComplex(QString name)
 {
-    return SubstitutionFileParser::IsSubstituted(((UIAppDesc*)appList[name])->getAppDesktopFile());
+    try
+    {
+	UIAppDesc* app = ((UIAppDesc*)appList[name]);
+	if(app)
+	    return SubstitutionFileParser::IsSubstituted(app->getAppDesktopFile());
+
+	qDebug() << "Returned app was null";
+	qDebug() << "   Name:" << name;
+	return false;
+    }
+    catch(...)
+    {
+	qDebug() << "Failed to check IsComplex(" << name << "); appList entry missing";
+	return false;
+    }
 }
 
 void UIDaemonHandler::RemoveApp(QString name)
